==> haskell-x509-1.7.5-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.5
id: x509-1.7.5-AGDNqwGGf1H926kJ4arIa9
key: x509-1.7.5-AGDNqwGGf1H926kJ4arIa9
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer. please see README
category: Data
abi: 5de9677295fc00447d03ac159a818fe4
exposed: True
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-1.7.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-1.7.5
hs-libraries: HSx509-1.7.5-AGDNqwGGf1H926kJ4arIa9
depends:
    asn1-encoding-0.9.5-1HooVrxELdT8EXBBjBMSfy
    asn1-parse-0.9.4-HMkmDWmd9eeIsjWLNEOH6r
    asn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    hourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.5-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.5
id: x509-1.7.5-HSY0xPcI4REFeHDt27wwza
key: x509-1.7.5-HSY0xPcI4REFeHDt27wwza
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer. please see README
category: Data
abi: 65b06544b61969a1d337bf3a829e82b3
exposed: True
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-1.7.5
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-1.7.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-1.7.5
hs-libraries: HSx509-1.7.5-HSY0xPcI4REFeHDt27wwza
depends:
    asn1-encoding-0.9.5-3LSg3WoNh6O3pQtXpbzGmR
    asn1-parse-0.9.4-8WAwTHFFgPnRUc2uvAzzx
    asn1-types-0.3.2-DLmgLG4DguzLHCJactuvzi base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    hourglass-0.2.12-6cegQbTCp2XGNMMF7vzGJo
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
